@@ -269,10 +269,10 @@ class ExchangeBase:
         )
         
 class Exchange(ExchangeBase):
-    def __init__(self, trade_symbols, fee=0.0002, initial_balance=10000, recorded=False):
+    def __init__(self, trade_symbols:list=[], fee=0.0002, initial_balance=10000, recorded=False):
         super().__init__(initial_balance=initial_balance, recorded=recorded)
         self.fee = fee
-        self.trade_symbols = trade_symbols
+        self.trade_symbols:list = trade_symbols
         self.id_gen = 0
         self.account['USDT'].update({
             'hold': 0,
@@ -280,8 +280,12 @@ class Exchange(ExchangeBase):
             'short': 0
         })
         for symbol in trade_symbols:
-            self.account[symbol] = {'amount': 0, 'hold_price': 0, 'value': 0, 'price': 0,
-                                     'realised_profit': 0, 'unrealised_profit': 0, 'fee': 0}
+            self.account[symbol] = self._act_template
+    
+    @property
+    def _act_template(self):
+        return {'amount': 0, 'hold_price': 0, 'value': 0, 'price': 0,
+                                     'realised_profit': 0, 'unrealised_profit': 0, 'fee': 0}.copy()
 
     def Trade(self, symbol, direction, price, amount, **kwargs):
         if self.recorded and 'time' not in kwargs:
@@ -307,8 +311,7 @@ class Exchange(ExchangeBase):
 
         if symbol not in self.trade_symbols:
             self.trade_symbols.append(symbol)
-            self.account[symbol] = {'amount': 0, 'hold_price': 0, 'value': 0, 'price': 0,
-                                     'realised_profit': 0, 'unrealised_profit': 0, 'fee': 0}
+            self.account[symbol] = self._act_template
 
         cover_amount = 0 if direction * self.account[symbol]['amount'] >= 0 else min(abs(self.account[symbol]['amount']), amount)
         open_amount = amount - cover_amount
@@ -332,6 +335,9 @@ class Exchange(ExchangeBase):
             self.account[symbol]['realised_profit'] += profit
             self.account[symbol]['amount'] -= -direction * cover_amount
             trade['pos'] = profit  # 记录盈亏
+      
+            trade['pos_rate'] = -direction * (price / self.account[symbol]['hold_price'] - 1) if self.account[symbol]['hold_price'] != 0 else 0
+
             self.account[symbol]['hold_price'] = 0 if self.account[symbol]['amount'] == 0 else self.account[symbol]['hold_price']
 
         if open_amount > 0:
@@ -343,6 +349,7 @@ class Exchange(ExchangeBase):
 
         if kwargs:
             self.opt.update(kwargs)
+            self.account[symbol].update(kwargs)
 
         # 记录账户总资产到 history
         if self.recorded:
@@ -350,7 +357,7 @@ class Exchange(ExchangeBase):
             self.record_history(time)
 
         # 自动更新账户状态
-        self.Update({symbol: price}, time=time)
+        self.Update({symbol: price},  time=time)
 
         return trade
 
@@ -377,41 +384,92 @@ class Exchange(ExchangeBase):
             trades.append(trade)
         return trades
 
-    def Update(self, close_price, symbols=None, **kwargs):
+    def _recalc_aggregates(self):
+        """基于 self.account 中已保存的各 symbol 状态，重算聚合字段。"""
+        usdt = self.account['USDT']
+        usdt['unrealised_profit'] = 0
+        usdt['hold'] = 0
+        usdt['long'] = 0
+        usdt['short'] = 0
+
+        for symbol in self.trade_symbols:
+            if symbol not in self.account:
+                continue
+            sym = self.account[symbol]
+            px = sym.get('price', 0)
+            amt = sym.get('amount', 0)
+            hp = sym.get('hold_price', 0)
+
+            # 仅当价格有效时计入聚合
+            if px is not None and not np.isnan(px) and px != 0:
+                sym['unrealised_profit'] = (px - hp) * amt
+                sym['value'] = amt * px
+
+                if amt > 0:
+                    usdt['long'] += sym['value']
+                elif amt < 0:
+                    usdt['short'] += sym['value']
+
+                usdt['hold'] += abs(sym['value'])
+                usdt['unrealised_profit'] += sym['unrealised_profit']
+
+        usdt['total'] = round(self.account['USDT']['realised_profit'] + self.initial_balance + usdt['unrealised_profit'], 6)
+        usdt['leverage'] = round(usdt['hold'] / usdt['total'] if usdt['total'] != 0 else 0.0, 3)
+
+    def Update(self, close_price=None, symbols=None, partial=True, **kwargs):
+        """
+        更新账户状态。
+        - partial=True：只更新给定 symbols 的逐符号状态，然后对所有符号做一次聚合重算（推荐）。
+        - partial=False：与原逻辑兼容；当提供一部分 symbol 时，也会聚合重算，不会清空未提供符号的信息。
+        
+        支持三种入参形式：
+        1) close_price 为 dict/Series：symbols 自动取其键/索引
+        2) close_price 为标量 + symbols 为单个字符串
+        3) 显式传 symbols=list[...]，close_price 为 dict/Series（从中取价）
+        如果既不传 close_price 也不传 symbols，则只做一次聚合重算（例如你先前已经手动修改了某些 symbol 的 price）。
+        """
         if self.recorded and 'time' not in kwargs:
             raise ValueError("Time parameter is required in recorded mode.")
 
         time = kwargs.get('time', pd.Timestamp.now())
-        self.account['USDT']['unrealised_profit'] = 0
-        self.account['USDT']['hold'] = 0
-        self.account['USDT']['long'] = 0
-        self.account['USDT']['short'] = 0
+
+        # 解析 symbols & 价格获取器
         if symbols is None:
-            # symbols = self.trade_symbols
-            # 如果symbols是dict类型, 则取出所有的key, 如果是Series类型, 则取出所有的index
             if isinstance(close_price, dict):
                 symbols = list(close_price.keys())
             elif isinstance(close_price, pd.Series):
-                symbols = close_price.index
+                symbols = list(close_price.index)
             else:
-                raise ValueError("Symbols should be a list, dict or Series.")
-            
-        for symbol in symbols:
-            if symbol not in self.trade_symbols:
-                continue
-            if not np.isnan(close_price[symbol]):
-                self.account[symbol]['unrealised_profit'] = (close_price[symbol] - self.account[symbol]['hold_price']) * self.account[symbol]['amount']
-                self.account[symbol]['price'] = close_price[symbol]
-                self.account[symbol]['value'] = self.account[symbol]['amount'] * close_price[symbol]
-                if self.account[symbol]['amount'] > 0:
-                    self.account['USDT']['long'] += self.account[symbol]['value']
-                if self.account[symbol]['amount'] < 0:
-                    self.account['USDT']['short'] += self.account[symbol]['value']
-                self.account['USDT']['hold'] += abs(self.account[symbol]['value'])
-                self.account['USDT']['unrealised_profit'] += self.account[symbol]['unrealised_profit']
+                symbols = []
+        elif isinstance(symbols, str):
+            symbols = [symbols]
 
-        self.account['USDT']['total'] = round(self.account['USDT']['realised_profit'] + self.initial_balance + self.account['USDT']['unrealised_profit'], 6)
-        self.account['USDT']['leverage'] = round(self.account['USDT']['hold'] / self.account['USDT']['total'], 3)
+        def get_px(sym):
+            if isinstance(close_price, (int, float, np.floating)) and len(symbols) == 1:
+                return float(close_price)
+            if isinstance(close_price, dict):
+                return close_price.get(sym, np.nan)
+            if isinstance(close_price, pd.Series):
+                return close_price.get(sym, np.nan)
+            return np.nan
+
+        # 仅更新传入的 symbols（部分更新，不动其它符号已保存信息）
+        for sym in symbols:
+            if sym not in self.trade_symbols or sym not in self.account:
+                # 未登记的交易对直接跳过（或可选择自动登记，但此处保持严格）
+                continue
+            px = get_px(sym)
+            if px is None or np.isnan(px):
+                # 价格无效则不覆盖旧价格
+                continue
+
+            self.account[sym]['price'] = float(px)
+            amt = self.account[sym]['amount']
+            self.account[sym]['value'] = amt * float(px)
+            # 不在这里算 unrealised_profit，聚合阶段统一算
+
+        # 无论 partial 与否，最后都用“账户中保存的所有 symbol 当前状态”做一次聚合重算
+        self._recalc_aggregates()
 
         # 记录账户总资产到 history
         if self.recorded:
