@@ -845,7 +845,8 @@ def _produce_date_opt_js(
                 let dateInput = document.getElementById('date-input');
                 endDate=dateInput.value;
                 if (endDate.indexOf("-")<0 && endDate.length>=6){{
-                    endDate=endDate.replace(/({{4}})({{2}})({{2}})/, "$1-$2-$3");
+                    endDate = endDate.replace(/^(\\d{4})(\\d{2})(\\d{2})$/, '$1-$2-$3');
+
                 }}
                 to_date(endDate);
             }});
@@ -895,7 +896,7 @@ def _produce_date_opt_js(
     """
     # 如果高度是用%设置的,要监听浏览器窗口大小变化事件实现图表自动变大小
     if height_type == "%":
-        resize_js = """
+        resize_js = r"""
             function resize_chart(){{
                 // 获取当前窗口的宽度和高度
                 let width = window.innerWidth;
